#pragma once  
/*
* This file is part of the HdFury Vertex API/DLL control library.

* Vertex and HDFURY are trademark of LegendSky Tech Co Ltd
*
* This program is free to redistribute and/or modify for the purpose of
* remote controlling HDFURY Vertex device.

* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
*
* For more information contact:
* LegendSky Tech Co Ltd, Peng Yung Ge Jingli Mansion,
* No.48 Beili Road South, Shenzhen, PRC
* contact@hdfury.com
* www.hdfury.com
*
*/

#define VERTEX_API __declspec(dllimport) 

/* usbOpen() opens and leaves open the USB connection. Make sure to close it at the end of the program with usbClose() */
/* If not used, each function will independently open and close a USB connection making it slower */
/* checkVertexUsb() can be used to check if Vertex is connected to USB - returns true if connected*/
VERTEX_API bool  checkVertexUsb();
VERTEX_API bool  usbOpen();				
VERTEX_API bool  usbClose();			

VERTEX_API bool  getVertexVersion(unsigned char *fwStr);		
/* returns 18 byte array with the current firmware version in the format: FW: 1.14.1.20 */

VERTEX_API bool  getVertexStatus(unsigned char *pVertexState);
/* This is the main fast get status function. Returns a 64 byte array Vertex internal states. 
Refer to VERTEX_STATUS enum to decode values. Examples:
unsigned char pStatus[64];
getVertexStatus(pStatus);
pStatus[eInPort] -- current input port
pStatus[eAutoSw] -- autoswitch status
pStatus[eSwState_edid] -- EDID slide switch position
...
*/

VERTEX_API bool  getStatusRx0(unsigned char * status);
/* returns 64 byte array to the current received RX0 video format. In splitter mode, RX0 and RX1 show the same values */
VERTEX_API bool  getStatusRx1(unsigned char * status);
/* returns 64 byte array to the current received RX1 video format. In splitter mode, RX0 and RX1 show the same values */
VERTEX_API bool  getStatusTx0(unsigned char * status);
/* returns 64 byte array to the current received TX0 video format */
VERTEX_API bool  getStatusTx1(unsigned char * status);
/* returns 64 byte array to the current received TX1 video format */
VERTEX_API bool  getStatusTx0Sink(unsigned char * status);
/* returns 64 byte array to the current connected TX0 sink capabilities */
VERTEX_API bool  getStatusTx1Sink(unsigned char * status);
/* returns 64 byte array to the current connected TX1 sink capabilities */

VERTEX_API bool  getStatusRx0Audio(unsigned char * status);
/* returns 31 byte array to the current received RX0 audio stream */
VERTEX_API bool  getStatusRx1Audio(unsigned char * status);
/* returns 31 byte array to the current received RX1 audio stream */

VERTEX_API bool  getAviInfoFrame(unsigned char * aviIf);
/* returns 17 byte array to the current received AVI infoframe */
VERTEX_API bool  getSpdInfoFrame(unsigned char * spdIf);
/* returns 31 byte array to the current received SPD infoframe */
VERTEX_API bool  getHdrInfoFrame(unsigned char * hdrIf);
/* returns 31 byte array to the current received HDR infoframe */
VERTEX_API bool  getAudInfoFrame(unsigned char * audIf);
/* returns 31 byte array to the current received AUD infoframe */
VERTEX_API bool  getHvsInfoFrame(unsigned char * hvsIf);
/* returns 31 byte array to the current received HDMI VSI infoframe */
VERTEX_API bool  getVsiInfoFrame(unsigned char * vsiIf);
/* returns 31 byte array to the current received VSI infoframe */

VERTEX_API bool  setInputPort(VERTEX_INPORT port);
VERTEX_API bool  setHdcpLevel(VERTEX_HDCP level);
VERTEX_API bool  setAutoSwitch(VERTEX_STATE state);
VERTEX_API bool  setAutoSwitchPrio(VERTEX_STATE state);

VERTEX_API bool  setScale(VERTEX_SCALE scale);
/* Applicable when the scale slide switch is in the middle position */

VERTEX_API bool  setAutoScaleNoUpscale(VERTEX_STATE state);
/* Autoscale upscales 1080p content to 4k by default if sink supports it. Set this state to disable automatic upscaling */
VERTEX_API bool  setAutoPreset4k30(VERTEX_AUTOPRESET4K30 preset);
VERTEX_API bool  setAutoPreset4k60(VERTEX_AUTOPRESET4K60 preset);
VERTEX_API bool  setAutoPreset4k60Hdr(VERTEX_AUTOPRESET4K60HDR preset);
/* the above functions configure the autoscaler properties depending on the incoming video format 
Frame rate changes are not supported therefore not all values are applicable for all modes */

VERTEX_API bool  setEdidMode(VERTEX_EDIDMODECUSTOM mode);
/* Applicable when the scale slide switch is in the middle position */
VERTEX_API bool  setEdidAlgo(VERTEX_EDIDALGO algo);
VERTEX_API bool  setEdidAudioFlags(VERTEX_AUDIOFLAGS flags);
VERTEX_API bool  setEdid3d(VERTEX_STATE state);
VERTEX_API bool  setEdidBt2020(VERTEX_STATE state);
VERTEX_API bool  setEdidYuv(VERTEX_STATE state);
VERTEX_API bool  setEdidHdr(VERTEX_HDR10 mode);
VERTEX_API bool  setEdidDolbyVision(VERTEX_STATE dvEnable, VERTEX_STATE dvRemove, VERTEX_STATE dvLimit);
/* EDID flags are applicable when EDID mode is automix */

VERTEX_API bool  setEdidCustomTable(int edidTop, int edidBot);
/* When Vertex is in custom EDID mode, this function selects the custom table for both RX ports.
Allowed range for edidBot = 1-100, edidTop = 0-100 where 0 is "follow BOT". Check Vertex manual for table details
Tables 1-10 are custom slots that can be written with writeCustomEdid() function
*/

VERTEX_API bool  getEdidRx(bool rxport, unsigned char *pEdidBuf);
/* returns 256 byte EDID array from the corresponding Vertex RX port. This EDID reflects what the source device reads from Vertex
rxport 0 = BOT, 1 = TOP */

VERTEX_API bool  getEdidTx(bool txport, unsigned char *pEdidBuf);
/* returns 256 byte EDID array from the corresponding Vertex TX port. This EDID reflects what the Vertex reads from the sink device
txport 0 = BOT, 1 = TOP */


VERTEX_API bool  writeCustomEdid(unsigned char indexEdid, unsigned char * pEdidBuf);
/* writes a custom EDID table to the custom slot selected by indexEdid. Range is 1-10. 256 byte array is written. 
No error checking or checksum calculations are performed - any table can be written*/

VERTEX_API bool  setOled(VERTEX_STATE state);
VERTEX_API bool  setOledFadeValue(unsigned char seconds);
VERTEX_API bool  setOledRotate(VERTEX_STATE state);
VERTEX_API bool  setOledReverse(VERTEX_STATE state);
VERTEX_API bool  setOledMenuPage(unsigned char state);
/* Configures the default OLED menu page upon startup. Range is 1-5*/
VERTEX_API bool  setLogoLed(VERTEX_STATE state);
/* Enables / disables the Vertex side LOGO lights */

VERTEX_API bool  setPort0ScalePara(
	VERTEX_SCALEPORT act4k60,
	VERTEX_SCALEPORT_CS cs4k60,
	VERTEX_SCALEPORT_DC dc4k60,
	VERTEX_SCALEPORT act4k30,
	VERTEX_SCALEPORT_CS cs4k30,
	VERTEX_SCALEPORT_DC dc4k30,
	VERTEX_SCALEPORT act1080p60,
	VERTEX_SCALEPORT_RESO scale1080p60,
	VERTEX_SCALEPORT_CS cs1080p60,
	VERTEX_SCALEPORT_DC dc1080p60,
	VERTEX_SCALEPORT act1080p30,
	VERTEX_SCALEPORT_RESO scale1080p30,
	VERTEX_SCALEPORT_CS cs1080p30,
	VERTEX_SCALEPORT_DC dc1080p30
);
/* Port0 [BOT] custom scaling parameters. BOT port can upscale. */

VERTEX_API bool  setPort1ScalePara(
	VERTEX_SCALEPORT act4k60,
	VERTEX_SCALEPORT_RESO scale4kp60,
	VERTEX_SCALEPORT_CS cs4k60,
	VERTEX_SCALEPORT_DC dc4k60,
	VERTEX_SCALEPORT act4k30,
	VERTEX_SCALEPORT_RESO scale4k30,
	VERTEX_SCALEPORT_CS cs4k30,
	VERTEX_SCALEPORT_DC dc4k30,
	VERTEX_SCALEPORT act1080p60,
	VERTEX_SCALEPORT_CS cs1080p60,
	VERTEX_SCALEPORT_DC dc1080p60,
	VERTEX_SCALEPORT act1080p30,	
	VERTEX_SCALEPORT_CS cs1080p30,
	VERTEX_SCALEPORT_DC dc1080p30
);
/* Port1 [TOP] custom scaling parameters. TOP port can downscale */

VERTEX_API bool setOsdCustomText(int osdLocX, int osdLocY, char * txt, VERTEX_STATE state);
/* Configures the location and the contents of the custom text. Max length is 35 bytes */

VERTEX_API bool setOsdParam(unsigned char osdEn, /* Enable or disable OSD */
	int osdLocX, int osdLocY,		/* OSD location, range is 1-1920 for X and 1-1080 for Y. 4K locations are scaled*/
	unsigned char osdColorFg,		/* OSD foreground color 0-31*/
	unsigned char osdColorBg,		/* OSD background color 0-31 */
	unsigned char osdColorBgRate,	/* OSD background fade level 1-7 */
	unsigned char osdInfoBits,		/* Bitfield to show various lines on OSD*/
	unsigned char osdFadeValue,		/* Fade the OSD info after this many seconds */
	unsigned char osdMaskEn,		/* Enable or disable OSD mask */
	int osdMaskX0, int osdMaskY0, int osdMaskX1, int osdMaskY1,	/* OSD mask location, x=1-1920, y=1-1080*/
	unsigned char osdMaskRate,		/* OSD mask transparency level 1-7 */
	unsigned char osdMaskGrayScale); /* OSD mask grayscale value 0-15 */
/* Bit field osdInfoBits:
Bit0 - Source name
Bit1 - Video decode
Bit2 - Video infoframe
Bit3 - HDR decode
Bit4 - HDR Infoframe
Bit5 - Audio decode
Bit6 - HDR info (0-TX info, 1-RX info)
Bit7 - Video info (0-TX info, 1-RX info)
*/

VERTEX_API bool  setHotPlug();							
/* hot plug the active input port */
VERTEX_API bool  setBaudRate(VERTEX_BAUDRATE rate);		
/* configure rs232 port baud rate */
VERTEX_API bool  setHtpcMode(VERTEX_STATE state);
VERTEX_API bool  setFactoryReset(VERTEX_RESETLEVEL level);

VERTEX_API bool  setCec(VERTEX_STATE state);			
/* Enable / Disable Vertex CEC engine */
VERTEX_API bool  setCecLa(VERTEX_CECLA la);				
/* Configure Vertex CEC engine either Audio System / Video Processor*/
VERTEX_API bool  setArcHbr(VERTEX_STATE state);			
/* Enable / Disable DD+ capability for ARC */
VERTEX_API bool  setCecCommand(unsigned char length, char * cecStr);
/*	Send CEC command if the CEC is enabled
	Min length 2 bytes, max length 16 bytes, example to turn off TV 50:36 
	char CEC[2] = { 0x50, 0x36 };
	unsigned char length = 2;
	setCecCommand(length, CEC);
*/

VERTEX_API bool  setHdrCustom(VERTEX_STATE state);		
/* Enable / Disable HDR custom string */
VERTEX_API bool  setHdrDisable(VERTEX_STATE state);		
/* Disable all TX HDR metadata */
VERTEX_API bool  setHdrInfoFrame(char * hdrIf);
/*	Configure HDR metadata infoframe to the sink. 
	Min content length is 4 bytes, max length 31 bytes. Example:
	char HDRIF[31] = { 0x87,0x01,0x1a,0xb0,0x02,0x00,0xc2,0x33, ... };
	setHdrInfoFrame(HDRIF);	
	The actual sent length is HEADER (4bytes) + payload length HDRIF[2].
	Make sure to issue setHdrCustom(STATE_ON) to activate sending this metadata 
*/

VERTEX_API bool  setAviCustom(VERTEX_STATE state);		
/* Enable / Disable AVI custom string */
VERTEX_API bool  setAviDisable(VERTEX_STATE state);		
/* Disable all TX AVI metadata */
VERTEX_API bool  setAviInfoFrame(char * aviIf);
/*	Configure AVI metadata infoframe to the sink
	Min content length is 4 bytes, max length 17 bytes. Example:
	char AVIIF[17] = { 0x82,0x02,0x0d,0xae,0x40,0xc0,0x60,0x61,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 };
	setAviInfoFrame(AVIIF);
	The actual sent length is HEADER (4bytes) + payload length AVIIF[2]. 
	Make sure to issue setAviCustom(STATE_ON) to activate sending this metadata
*/

VERTEX_API bool  setVsiCustom(VERTEX_STATE state);		
/* Enable / Disable VSI custom string */
VERTEX_API bool  setVsiDisable(VERTEX_STATE state);		
/* Disable all TX VSI metadata */
VERTEX_API bool  setVsiInfoFrame(char * vsiIf);
/*	Configure VSI metadata infoframe to the sink
	Min content length is 4 bytes, max length 31 bytes. Example:
	char VSIIF[31] = { 0x81,0x01,0x1b,0x63,0x00,0x00,0x00,0x00, ... };
	setVsiInfoFrame(VSIIF);
	The actual sent length is HEADER (4bytes) + payload length VSIIF[2].
	Make sure to issue setVsiCustom(STATE_ON) to activate sending this metadata
*/

